/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EventEmitter, ElementRef, ChangeDetectorRef, NgZone, AfterViewInit, OnDestroy, QueryList, OnInit, Renderer2 } from '@angular/core';
import { Observable } from 'rxjs';
import { ResizeSensorComponent } from '@progress/kendo-angular-common';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { BreadCrumbItemModel, BreadCrumbItem } from './models/breadcrumb-item.interface';
import { BreadCrumbCollapseMode } from './models/collapse-mode';
import { BreadCrumbItemTemplateDirective } from './template-directives/item-template.directive';
import { BreadCrumbListComponent } from './list.component';
import { SVGIcon } from '@progress/kendo-angular-icons';
import { BreadcrumbSize } from './models/breadcrumb-size';
import * as i0 from "@angular/core";
/**
 * Represents the [Kendo UI Breadcrumb component for Angular]({% slug overview_breadcrumb %}).
 *
 * @example
 * ```ts-no-run
 * _@Component({
 *      selector: 'my-app',
 *      template: `
 *          <kendo-breadcrumb
 *              [items]="items"
 *              (itemClick)="onItemClick($event)">
 *          </kendo-breadcrumb>
 *      `
 * })
 * class AppComponent {
 *      public items: BreadCrumbItem[] = [
 *          { text: 'Home', title: 'Home', icon: 'home' },
 *          { text: 'Kids', title: 'Kids' },
 *          { text: '8y-16y', title: '8y-16y', disabled: true },
 *          { text: 'New collection', title: 'New collection' },
 *          { text: 'Jeans', title: 'Jeans' }
 *      ];
 *
 *      public onItemClick(item: BreadCrumbItem): void {
 *          console.log(item);
 *      }
 * }
 * ```
 */
export declare class BreadCrumbComponent implements OnInit, AfterViewInit, OnDestroy {
    private localization;
    private el;
    private cdr;
    private zone;
    private renderer;
    /**
     * The collection of items that will be rendered in the Breadcrumb.
     */
    set items(items: any[]);
    get items(): any[];
    /**
     * Defines a name of a [built-in icon]({% slug icons %}) in a Kendo UI theme.
     */
    separatorIcon: string;
    /**
     * Defines an [`SVGIcon`](slug:api_icons_svgicon) to be rendered as a separator.
     */
    separatorSVGIcon: SVGIcon;
    /**
     * Specifies the collapse mode of the Breadcrumb ([see example]({% slug collapse_modes_breadcrumb %})).
     *
     * The possible values are:
     * - `auto` (default)&mdash;items are automatically collapsed based on the width of the Breadcrumb.
     * - `wrap`&mdash;items are wrapped on multiple rows.
     * - `none`&mdash;all items are expanded on the same row.
     *
     * For more information and example refer to the [Collapse Modes]({% slug collapse_modes_breadcrumb %}) article.
     */
    set collapseMode(mode: BreadCrumbCollapseMode);
    get collapseMode(): BreadCrumbCollapseMode;
    /**
     * Specifies the padding of all Breadcrumb elements.
     *
     * The possible values are:
     * * `small`
     * * `medium` (default)
     * * `large`
     * * `none`
     */
    set size(size: BreadcrumbSize);
    get size(): BreadcrumbSize;
    /**
     * Fires when a Breadcrumb item is clicked. The event will not be fired by disabled items and the last item.
     */
    itemClick: EventEmitter<BreadCrumbItem>;
    /**
     * @hidden
     */
    resizeSensor: ResizeSensorComponent;
    /**
     * @hidden
     */
    itemsContainers: QueryList<ElementRef<HTMLOListElement>>;
    /**
     * @hidden
     */
    listComponent: BreadCrumbListComponent;
    /**
     * @hidden
     */
    itemTemplate: BreadCrumbItemTemplateDirective;
    hostClasses: boolean;
    get wrapMode(): boolean;
    hostAriaLabel: string;
    get getDir(): string;
    itemsData$: Observable<BreadCrumbItemModel[]>;
    firstItem$: Observable<BreadCrumbItemModel[]>;
    private _items;
    private _collapseMode;
    private _size;
    private updateItems;
    private afterViewInit;
    private subscriptions;
    private direction;
    constructor(localization: LocalizationService, el: ElementRef<HTMLElement>, cdr: ChangeDetectorRef, zone: NgZone, renderer: Renderer2);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    private handleResize;
    private shouldResize;
    private attachResizeHandler;
    private handleClasses;
    private resizeHandler;
    static ɵfac: i0.ɵɵFactoryDeclaration<BreadCrumbComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<BreadCrumbComponent, "kendo-breadcrumb", ["kendoBreadCrumb"], { "items": { "alias": "items"; "required": false; }; "separatorIcon": { "alias": "separatorIcon"; "required": false; }; "separatorSVGIcon": { "alias": "separatorSVGIcon"; "required": false; }; "collapseMode": { "alias": "collapseMode"; "required": false; }; "size": { "alias": "size"; "required": false; }; }, { "itemClick": "itemClick"; }, ["itemTemplate"], never, true, never>;
}
